==> corded-1.0.0.tar.gz: corded-1.0.0/corded/http/route.py <==
"""
MIT License

Copyright (c) 2021 vcokltfre

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


class Route:
    def __init__(self, path: str, **params):
        """Represents a Discord API route, used for ratelimit handling.

        Args:
            path (str): The API path to use.
            params: The parameters to format the path with.
        """

        self.route = path.format(**params)

        # Key ratelimit handling parameters
        guild_id = params.get("guild_id", 0)
        channel_id = params.get("channel_id", 0)
        webhook_id = params.get("webhook_id", 0)

        self.bucket = f"{guild_id}-{channel_id}-{webhook_id}::{path}"

==> corded-1.5.0.tar.gz: corded-1.5.0/corded/http/route.py <==
"""
MIT License

Copyright (c) 2021 vcokltfre

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


class Route:
    def __init__(self, path: str, **params) -> None:
        """Represents a Discord API route, used for ratelimit handling.

        Args:
            path (str): The API path to use.
            params: The parameters to format the path with.
        """

        self.route = path.format(**params)

        # Key ratelimit handling parameters
        guild_id = params.get("guild_id", 0)
        channel_id = params.get("channel_id", 0)
        webhook_id = params.get("webhook_id", 0)

        self.bucket = f"{guild_id}-{channel_id}-{webhook_id}::{path}"
